function PWBLog:CreateOptions()
	local L = LibStub("AceLocale-3.0"):GetLocale("Protwarbar")
	local media = LibStub("LibSharedMedia-3.0")
	local fonts = media:List("font")

	local options = {
		type = "group",
		name = L["Information"],
		childGroups = "tab",
		args = {
			group1 = {
				name = L["General"],
				type = "group",
				order = 1,
				args = {
					enable = {
					  order = 1,
					  name = L["Enable"],
					  desc = L["Enable this module"],
					  type = "toggle",
					  set = function(info,val) self.db.enabled = val PWBLog:RefreshConfig() end,
					  get = function(info) return self.db.enabled end
					},
				}
			},
			group2 = {
				name = L["Position"],
				type = "group",
				order = 2,
				args = {
					desc_pos = {
						type = 'header',
						name = L["Position"],
						order = 2,
					},
					x = {
						order = 4,
						name = L["X"],
						desc = L["X position"],
						type = "range",
						min = 1,
						max = 2560,
						step = 1,
						set = function(info,val) self.db.x = val PWBLog:RefreshConfig() end,
						get = function(info) return self.db.x end
					},
					you = {
						order = 5,
						name = L["Y"],
						desc = L["Y position"],
						type = "range",
						min = 1,
						max = 2048,
						step = 1,
						set = function(info,val) self.db.y = val PWBLog:RefreshConfig() end,
						get = function(info) return self.db.y end
					},
					desc_6 = {
						type = 'description',
						name = " ",
						order = 6,
					},
					venwidth = {
						order = 7,
						name = L["Width"],
						desc = L["Width"],
						type = "range",
						min = 5,
						max = 200,
						step = 1,
						set = function(info,val) self.db.width = val PWBLog:RefreshConfig() end,
						get = function(info) return self.db.width end
					},
					venheight = {
						order = 8,
						name = L["Height"],
						desc = L["Height"],
						type = "range",
						min = 5,
						max = 200,
						step = 1,
						set = function(info,val) self.db.height = val PWBLog:RefreshConfig() end,
						get = function(info) return self.db.height end
					},
				},
			},
			group3 = {
				name = L["Appearance"],
				type = "group",
				order = 3,
				args = {
					enable = {
						order = 1,
						name = L["Use defaults"],
						desc = L["Use defaults"],
						type = "toggle",
						set = function(info,val) self.db.useDefaults = val PWBLog:RefreshConfig() end,
						get = function(info) return self.db.useDefaults end
					},
					desc_ven_head = {
						type = 'header',
						name = L["Font options"],
						order = 10,
					},
					venfontsize = {
						order = 11,
						name = L["Font Size"],
						desc = L["Font Size"],
						type = "range",
						disabled = function() return self.db.useDefaults == true end,
						min = 3,
						max = 50,
						step = 1,
						set = function(info,val) self.db.fontsize = val PWBLog:RefreshConfig() end,
						get = function(info) return self.db.fontsize end
					},
					venFont = {
						name = L["Font"],
						desc = L["Font"],
						type = "select",
						disabled = function() return self.db.useDefaults == true end,
						values = fonts,
						order = 13,
						set = function(info, v)
								self.db.font = media:List("font")[v]
								PWBLog:RefreshConfig()
							end,
						get = function(info) return Protwarbar:GetLSMIndex("font", self.db.font) end
					},

					desc_bg = {
						type = 'header',
						name = L["Frame options"],
						order = 21,
					},
					bg = {
						name = L["Background color"],
						desc = L["Background color"],
						type = "color",
						disabled = function() return self.db.useDefaults == true end,
						order = 22,
						width = "normal",
						hasAlpha = true,
						set = function(info, r, g, b, a)
								self.db.background[1] = r;
								self.db.background[2] = g;
								self.db.background[3] = b;
								self.db.background[4] = a;
								PWBLog:RefreshConfig()
								end,
						get = function(info) return self.db.background[1], self.db.background[2],
													self.db.background[3], self.db.background[4]
							end
					},
				},
			},


		}
	}

	return options
end